// -------------------------------------------------------------------------
// PARAMETERS:
// -------------------------------------------------------------------------

//transforms
float4x4 tW: WORLD;        //the models world matrix
float4x4 tV: VIEW;         //view matrix as set via Renderer (DX9)
float4x4 tP: PROJECTION;   //projection matrix as set via Renderer (DX9)
float4x4 tWVP: WORLDVIEWPROJECTION; 

//texture
texture Tex <string uiname="Camera stream";>;
texture Tex2 <string uiname="Camera2 stream";>;
sampler Samp = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (Tex);          //apply a texture to the sampler
    MipFilter = LINEAR;         //sampler states
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};
sampler Samp2 = sampler_state    //sampler for doing the texture-lookup
{
    Texture   = (Tex2);          //apply a texture to the sampler
    MipFilter = LINEAR;         //sampler states
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

//texture transformation marked with semantic TEXTUREMATRIX to achieve symmetric transformations
float4x4 tTex: TEXTUREMATRIX <string uiname="Texture Transform";>;

float threshold <string uiname="threshold";>  = 0.10;

//the data structure: "vertexshader to pixelshader"
//used as output data with the VS function
//and as input data with the PS function
struct vs2ps
{
    float4 Pos : POSITION;
    float4 TexCd : TEXCOORD0;
};
// --------------------------------------------------------------------------------------------------
// VERTEXSHADERS
// --------------------------------------------------------------------------------------------------

vs2ps VS(
    float4 Pos : POSITION,
    float4 TexCd : TEXCOORD0)
{
    //inititalize all fields of output struct with 0
    vs2ps Out = (vs2ps)0;

    //transform position
    Out.Pos = mul(Pos, tWVP);

    //transform texturecoordinates
    Out.TexCd = mul(TexCd, tTex);

    return Out;
}

// -------------------------------------------------------------------------
// PIXELSHADERS:
// -------------------------------------------------------------------------

float4 makeAnaglyph(vs2ps In): COLOR
{
    float4 color;
    //texture lookup to access the pixels of the texture
    float4 col = tex2D(Samp,  float2( In.TexCd.x+threshold, In.TexCd.y));
    float4 col2 = tex2D(Samp2, float2( In.TexCd.x-threshold, In.TexCd.y));
    color = float4(col.x,col2.y,col2.z,1);
    return color;
}

float pictureChange(float2 pointA) {
    float4 color;
    float4 col = tex2D(Samp, float2( pointA.x,pointA.y));
    float4 col2 = tex2D(Samp2, float2( pointA.x,pointA.y));
    //then return color
    float4 minus = col - col2;
    float vzdalenost = sqrt( minus.x*minus.x + minus.y*minus.y + minus.z*minus.z );
    return vzdalenost;
}

// -------------------------------------------------------------------------
// TECHNIQUES:
// -------------------------------------------------------------------------




technique Anaglyph //name for the technique pin
{
    pass P0
    {
        VertexShader = compile vs_1_1 VS();
        PixelShader  = compile ps_2_0 makeAnaglyph();
    }
}

